@@ -5,7 +5,7 @@
 
 
 
-.startWriteCDF <- function(x, filename, datatype='FLT4S', overwrite=FALSE, progress='', att, varname, varunit, varatt, longname, xname, yname, zname, zunit, zatt, NAflag, force_v4=FALSE, ...) {
+.startWriteCDF <- function(x, filename, datatype='FLT4S', overwrite=FALSE, progress='', att, varname, varunit, varatt, longname, xname, yname, zname, zunit, zatt, NAflag, force_v4=FALSE, sources, ...) {
 
 	stopifnot(requireNamespace("ncdf4"))
 		
@@ -13,6 +13,7 @@
 	if (filename == '') { 
 		stop('provide a filename') 
 	}
+	
 	extension(filename) <- .defaultExtension(format='CDF')
 	if (file.exists(filename) & !overwrite) {
 		stop('file exists, use overwrite=TRUE to overwrite it')
@@ -107,7 +108,7 @@
 	nc <- ncdf4::nc_create(filename, defs, force_v4=force_v4)
 	prj <- crs(x)
 	if (!is.na(prj)) {
-		ncdf4::ncatt_put(nc, "crs", "proj4",  sp::proj4string(prj), prec='text')
+		ncdf4::ncatt_put(nc, "crs", "proj4", proj4string(prj), prec='text')
 		ncdf4::ncatt_put(nc, varname, "grid_mapping", "crs")
 		ncdf4::ncatt_put(nc, varname, "proj4", as.character(prj), prec='text')
 	}
@@ -159,12 +160,18 @@
 }
 
 
-.stopWriteCDF <-  function(x) {
+.writeRangeCDF <- function(x) {
+
 	nc <- ncdf4::nc_open(x@file@name, write=TRUE)
 	on.exit( ncdf4::nc_close(nc) )
 	ncdf4::ncatt_put(nc, x@title, 'min', as.numeric(x@data@min))
 	ncdf4::ncatt_put(nc, x@title, 'max', as.numeric(x@data@max))
+}
 
+
+.stopWriteCDF <-  function(x) {
+
+        .writeRangeCDF(x)
 	if (inherits(x, 'RasterBrick')) {
 		r <- brick(x@file@name)
 	} else {
